summaryrefslogtreecommitdiff
path: root/kwebapp/kwebmain.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kwebapp/kwebmain.cpp')
-rw-r--r--kwebapp/kwebmain.cpp71
1 files changed, 42 insertions, 29 deletions
diff --git a/kwebapp/kwebmain.cpp b/kwebapp/kwebmain.cpp
index 639d1533..a0848946 100644
--- a/kwebapp/kwebmain.cpp
+++ b/kwebapp/kwebmain.cpp
@@ -1,44 +1,54 @@
-/*
- * This file is part of the KDE project.
- * Copyright (C) 2011 by Andrea Diamantini <adjam7@gmail.com>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) version 3, or any
- * later version accepted by the membership of KDE e.V. (or its
- * successor approved by the membership of KDE e.V.), which shall
- * act as a proxy defined in Section 6 of version 3 of the license.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library. If not, see <http://www.gnu.org/licenses/>.
- */
+/* ============================================================
+*
+* This file is a part of the rekonq project
+*
+* Copyright (C) 2011-2012 by Andrea Diamantini <adjam7 at gmail dot com>
+*
+*
+* This program is free software; you can redistribute it and/or
+* modify it under the terms of the GNU General Public License as
+* published by the Free Software Foundation; either version 2 of
+* the License or (at your option) version 3 or any later version
+* accepted by the membership of KDE e.V. (or its successor approved
+* by the membership of KDE e.V.), which shall act as a proxy
+* defined in Section 14 of version 3 of the license.
+*
+* This program is distributed in the hope that it will be useful,
+* but WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+* GNU General Public License for more details.
+*
+* You should have received a copy of the GNU General Public License
+* along with this program. If not, see <http://www.gnu.org/licenses/>.
+*
+* ============================================================ */
-#include "webview.h"
+// Local Includes
+#include "rekonqview.h"
-#include <KDE/KApplication>
-
-#include <KDE/KAboutData>
-#include <KDE/KCmdLineArgs>
+// KDE Includes
+#include <KApplication>
+#include <KAboutData>
+#include <KCmdLineArgs>
+#include <KUrl>
+#include <KStandardDirs>
+// Qt Includes
+#include <QWebSettings>
#include <QDebug>
-#include <QUrl>
+
static const char description[] =
I18N_NOOP("Web Application Viewer");
-static const char version[] = "0.1";
+static const char version[] = "0.2";
+
int main(int argc, char **argv)
{
KAboutData about("kwebapp", 0, ki18n("kwebapp"), version, ki18n(description),
- KAboutData::License_GPL, ki18n("(C) 2011 Andrea Diamantini"), KLocalizedString(), 0, "adjam7@gmail.com");
+ KAboutData::License_GPL, ki18n("(C) 2011-2012 Andrea Diamantini"), KLocalizedString(), 0, "adjam7@gmail.com");
about.addAuthor(ki18n("Andrea Diamantini"), KLocalizedString(), "adjam7@gmail.com");
KCmdLineArgs::init(argc, argv, &about);
@@ -48,6 +58,8 @@ int main(int argc, char **argv)
KApplication app;
+ QWebSettings::setIconDatabasePath(KStandardDirs::locateLocal("cache", "kwebapp.favicons/"));
+ qDebug() << "ICON PATH: " << KStandardDirs::locateLocal("cache", "kwebapp.favicons/");
KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
if (args->count() != 1)
{
@@ -55,7 +67,8 @@ int main(int argc, char **argv)
return 0;
}
- WebView *widg = new WebView(QUrl::fromUserInput(args->arg(0)));
+ RekonqView *widg = new RekonqView();
+ widg->loadUrl(KUrl(QUrl::fromUserInput(args->arg(0))));
widg->show();
args->clear();